import type { Metadata, Viewport } from "next";
import Providers from "./provider";
import { getServerSession } from "next-auth";
import { Session } from "next-auth";
import { nextauthOptions } from "./lib/nextauth-options";

const APP_NAME = "Medianet & Sons";
const APP_DEFAULT_TITLE = "Medianet & Sons";
const APP_TITLE_TEMPLATE = "%s - medianet & sons";
const APP_DESCRIPTION = "Medianet & Sons Pvt .Ltd";

export const metadata: Metadata = {
  applicationName: APP_NAME,
  title: {
    default: APP_DEFAULT_TITLE,
    template: APP_TITLE_TEMPLATE,
  },
  description: APP_DESCRIPTION,
  appleWebApp: {
    capable: true,
    statusBarStyle: "default",
    title: APP_DEFAULT_TITLE,
    // startUpImage: [],
  },
  formatDetection: {
    telephone: false,
  },
  openGraph: {
    type: "website",
    siteName: APP_NAME,
    title: {
      default: APP_DEFAULT_TITLE,
      template: APP_TITLE_TEMPLATE,
    },
    description: APP_DESCRIPTION,
  },
  twitter: {
    card: "summary",
    title: {
      default: APP_DEFAULT_TITLE,
      template: APP_TITLE_TEMPLATE,
    },
    description: APP_DESCRIPTION,
  },
};

export const viewport: Viewport = {
  themeColor: "#FFFFFF",
};


export default async function RootLayout({ children }: { children: React.ReactNode }) {
  const session: Session = await getServerSession(nextauthOptions);
  const currentUser = session?.user ?? null
  const batchStatus = session?.batchStatus ?? [];
  const locationStatus = session?.locationStatus ?? [];
  const assignmentStatus = session?.assignmentStatus ?? [];
  const projects = session?.projects ?? [];
  const currentProjectId = session?.currentProjectId ?? '';

  return (
    <html lang="en" suppressHydrationWarning>
      <body id={"root"}>
        <Providers currentUser={currentUser} batchStatus={batchStatus} locationStatus={locationStatus} assignmentStatus={assignmentStatus} projects={projects} currentProjectId={currentProjectId}>
          {children}
        </Providers>
      </body>
    </html>
  );
}
